#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Dict

import pydantic
from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry.v2.aip_agents.models._agent_markdown_response import AgentMarkdownResponse
from foundry.v2.aip_agents.models._parameter_id import ParameterId
from foundry.v2.aip_agents.models._parameter_value_update_dict import (
    ParameterValueUpdateDict,
)  # NOQA


class SessionExchangeResultDict(TypedDict):
    """The returned result from the Agent for a session exchange."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    agentMarkdownResponse: AgentMarkdownResponse
    """The final text response generated by the Agent. Responses are formatted using markdown."""

    parameterUpdates: Dict[ParameterId, ParameterValueUpdateDict]
    """
    Any updates to parameters which were generated by the Agent for this exchange.
    Updates can only be generated for parameter values that were provided as input to the Agent and that are configured with `READ_WRITE` access on the Agent in AIP Agent Studio.
    """

    totalTokensUsed: NotRequired[pydantic.StrictInt]
    """Total tokens used to compute the result. Omitted if token usage information is not supported by the model used for the session."""

    interruptedOutput: pydantic.StrictBool
    """
    True if the exchange was canceled.
    In that case, the response (if any) was provided by the client as part of the cancellation request rather than by the Agent.
    """
